@@ -3,14 +3,18 @@ import logging
 import os
 import re
 import sys
+import tempfile
 import webbrowser
 from datetime import datetime
 
 from dateutil import tz
 from rich.console import Console
-from ruamel import yaml
+from piperider_cli import yaml as pyml
 
 PIPERIDER_USER_HOME = os.path.expanduser('~/.piperider')
+if os.access(os.path.expanduser('~/'), os.W_OK) is False:
+    # If we can't create file in user home directory, fallback to use temp folder
+    PIPERIDER_USER_HOME = os.path.join(tempfile.gettempdir(), '.piperider')
 PIPERIDER_USER_PROFILE = os.path.join(PIPERIDER_USER_HOME, 'profile.yml')
 
 
@@ -32,6 +36,22 @@ def create_logger(name) -> logging.Logger:
     return log
 
 
+def is_executed_manually() -> bool:
+    # some CI service puts the "CI" var
+    if os.environ.get('CI', 'false') == 'true':
+        return False
+
+    # For CiecleCI exceptions
+    if os.environ.get('CIRCLECI', 'false') == 'true':
+        return False
+
+    # if not tty, it probably runs automatically
+    if not sys.stdout.isatty():
+        return False
+
+    return True
+
+
 def get_assertion_dir():
     return os.environ.get('PIPERIDER_CUSTOM_ASSERTIONS_PATH', '')
 
@@ -59,7 +79,7 @@ def get_sentry_dns():
 
 def get_user_id():
     with open(PIPERIDER_USER_PROFILE, 'r') as f:
-        user_profile = yaml.YAML().load(f)
+        user_profile = pyml.load(f)
         return user_profile.get('user_id')
 
 
@@ -139,28 +159,6 @@ def raise_exception_when_directory_not_writable(output):
             raise Exception(f'The path "{output}" is not writable')
 
 
-def safe_load_yaml(file_path):
-    try:
-        with open(file_path, 'r') as f:
-            payload = yaml.safe_load(f)
-    except yaml.YAMLError as e:
-        print(e)
-        return None
-    except FileNotFoundError:
-        return None
-    return payload
-
-
-def round_trip_load_yaml(file_path):
-    with open(file_path, 'r') as f:
-        try:
-            payload = yaml.round_trip_load(f)
-        except yaml.YAMLError as e:
-            print(e)
-            return None
-    return payload
-
-
 def load_json(file_path):
     with open(file_path, 'r') as f:
         try:
@@ -171,11 +169,80 @@ def load_json(file_path):
     return payload
 
 
+def _init_jinja_env(env):
+    def env_var(var, default=None):
+        if var is None:
+            return var
+        return os.getenv(var, default)
+
+    def as_bool(var):
+        if var is None:
+            return var
+        return var.lower() in ('true', 'yes', '1')
+
+    def as_number(var):
+        if var is None:
+            return var
+
+        # the input has been a numeric value
+        if isinstance(var, int) or isinstance(var, float):
+            return var
+
+        # the input is str, but could convert to a numeric value
+        try:
+            if isinstance(var, str):
+                if var.isnumeric():
+                    return int(var)
+                else:
+                    return float(var)
+        except BaseException:
+            # fail to covert
+            raise
+        # unknown cases
+        return var
+
+    def as_text(var):
+        if var is None:
+            return var
+        return str(var)
+
+    def silent_none(var):
+        if var is None:
+            return ""
+        return var
+
+    env.globals['env_var'] = env_var
+    env.filters['as_bool'] = as_bool
+    env.filters['as_number'] = as_number
+    env.filters['as_text'] = as_text
+    env.finalize = silent_none
+
+
+def load_jinja_template(path: str):
+    from jinja2 import Environment, FileSystemLoader
+
+    env = Environment(loader=FileSystemLoader(searchpath=os.path.dirname(path)))
+    _init_jinja_env(env)
+    template = env.get_template(os.path.basename(path))
+
+    return template
+
+
+def load_jinja_string_template(value: str):
+    from jinja2 import Environment, BaseLoader
+
+    env = Environment(loader=BaseLoader())
+    _init_jinja_env(env)
+    template = env.from_string(value)
+
+    return template
+
+
 def open_report_in_browser(report_path='', is_cloud_path=False):
     protocol_prefix = "" if is_cloud_path else "file://"
     try:
         webbrowser.open(f"{protocol_prefix}{report_path}")
-    except yaml.YAMLError as e:
+    except pyml.YAMLError as e:
         print(e)
         return None
 
@@ -203,4 +270,4 @@ def get_run_json_path(output_dir: str, input=None):
                     latest_report_dir_ctime = os.path.getctime(de)
                     latest_report_dir = de.path
             run_json = os.path.join(output_dir, latest_report_dir, 'run.json')
-    return run_json
+    return os.path.abspath(run_json)
