@@ -1,27 +1,24 @@
+import json
 import os.path
 import sys
+import typing as t
 
 import click
 import sentry_sdk
+from click import Context, Parameter
 from rich.console import Console
 
-import piperider_cli.dbtutil as dbtutil
-from piperider_cli import __version__, sentry_dns, sentry_env, event
-from piperider_cli.assertion_generator import AssertionGenerator
-from piperider_cli.cloud_connector import CloudConnector
-from piperider_cli.compare_report import CompareReport
-from piperider_cli.configuration import PIPERIDER_WORKSPACE_PATH
-from piperider_cli.error import RecipeConfigException
+from piperider_cli import __version__, event, sentry_dns, sentry_env
+from piperider_cli.cli_utils import DbtUtil, verify_upload_related_options
+from piperider_cli.cli_utils.cloud import CloudConnectorHelper
+from piperider_cli.configuration import FileSystem, is_piperider_workspace_exist
+from piperider_cli.error import DbtProjectNotFoundError
 from piperider_cli.event import UserProfileConfigurator
 from piperider_cli.event.track import TrackCommand
-from piperider_cli.exitcode import EC_ERR_TEST_FAILED
 from piperider_cli.feedback import Feedback
 from piperider_cli.generate_report import GenerateReport
 from piperider_cli.guide import Guide
 from piperider_cli.initializer import Initializer
-from piperider_cli.recipe_executor import RecipeExecutor
-from piperider_cli.runner import Runner
-from piperider_cli.validator import Validator
 
 release_version = __version__ if sentry_env != 'development' else None
 
@@ -44,6 +41,43 @@ debug_option = [
 ]
 
 
+def dbt_select_option_builder():
+    try:
+        # For dbt-core >= 1.5.0
+        from dbt.cli.options import MultiOption
+        return click.option('--select', '-s', default=None, type=tuple, help='Specify the dbt nodes to include.',
+                            multiple=True,
+                            cls=MultiOption)
+    except Exception:
+        # For dbt-core < 1.5.0
+        return click.option('--select', '-s', default=None, help='Specify the dbt nodes to include.',
+                            multiple=True)
+
+
+dbt_related_options = [
+    click.option('--dbt-project-dir', type=click.Path(exists=True),
+                 help='The path to the dbt project directory.'),
+    click.option('--dbt-target', type=click.STRING, default=None,
+                 help='Specify which dbt target to load for the given dbt profile.'),
+    click.option('--dbt-profiles-dir', type=click.Path(exists=True), default=None,
+                 help='Directory to search for dbt profiles.yml.'),
+    click.option('--dbt-profile', type=click.STRING, default=None,
+                 help='Specify which dbt profile to load. Overrides setting in dbt_project.yml.'),
+    click.option('--no-auto-search', type=click.BOOL, default=False, is_flag=True,
+                 help='Disable auto detection of dbt projects.'),
+
+]
+
+# Quick Look (https://cloud.piperider.io/quick-look) is a public-facing page on PipeRider Cloud.
+# Every user can paste the GitHub repo or PR URL, and PipeRider Cloud will analyze that URL by the CLI on the air.
+# The reports on the Quick Look are default shared public with a limited time.
+# PipeRider Cloud uses this feature flag to upload those reports to the Quick Look storage.
+feature_flags = [
+    click.option('--enable-quick-look-share', envvar='PIPERIDER_ENABLE_QUICK_LOOK_SHARE',
+                 is_flag=True, default=False, hidden=True, help='Enable share to Quick Look.')
+]
+
+
 def add_options(options):
     def _add_options(func):
         for option in reversed(options):
@@ -53,10 +87,46 @@ def add_options(options):
     return _add_options
 
 
+class RunDataPath(click.Path):
+    def __init__(self):
+        super().__init__(exists=True, dir_okay=False, resolve_path=True)
+
+    def convert(
+        self, value: t.Any, param: t.Optional["Parameter"], ctx: t.Optional["Context"]
+    ) -> t.Any:
+        rv = value
+
+        try:
+            data = self.read_file(rv)
+            self.validate(data)
+        except BaseException as e:
+            self.fail(f'{e} from: "{value}"')
+            pass
+
+        return super().convert(rv, param, ctx)
+
+    def read_file(self, rv):
+        try:
+            with open(rv) as fh:
+                return json.loads(fh.read())
+        except BaseException:
+            raise ValueError('failed to read data')
+
+    def validate(self, data):
+        if not isinstance(data, t.Dict):
+            raise ValueError('type mismatched, we expected a dict')
+        required_keys = {'tables', 'datasource'}
+        if not set(data.keys()).issuperset(required_keys):
+            raise ValueError(f'missing one of required keys: {required_keys}')
+
+        if 'dbt' in data and data.get('dbt', {}).get('manifest') is None:
+            raise ValueError('there is no dbt manifest data in the run.json')
+
+
 @click.group(name="piperider", invoke_without_command=True)
 @click.pass_context
 def cli(ctx: click.Context):
-    'An open-source toolkit for detecting data issues across pipelines that works with CI systems for continuous data quality assessment.'
+    'Code review for data in dbt'
     if ctx.invoked_subcommand is None:
         click.echo(ctx.get_help())
         Guide().show_tips(ctx.command.name)
@@ -92,36 +162,30 @@ def feedback():
 
 
 @cli.command(short_help='Initialize a PipeRider project.', cls=TrackCommand)
-@click.option('--no-auto-search', type=click.BOOL, default=False, is_flag=True,
-              help="Disable auto detection of dbt projects.")
-@click.option('--dbt-project-dir', type=click.Path(exists=True), default=None,
-              help='Directory to search for dbt_project.yml.')
-@click.option('--dbt-profiles-dir', type=click.Path(exists=True), default=None,
-              help='Directory to search for dbt profiles.yml.')
+@add_options(dbt_related_options)
 @add_options(debug_option)
 def init(**kwargs):
     'Initialize a PipeRider project in interactive mode. The configurations are saved in ".piperider".'
 
     console = Console()
 
-    # TODO show the process and message to users
-    console.print(f'Initialize piperider to path {PIPERIDER_WORKSPACE_PATH}')
-
     # Search dbt project config files
-    dbt_project_path = None
     dbt_project_dir = kwargs.get('dbt_project_dir')
-    dbt_profiles_dir = kwargs.get('dbt_profiles_dir')
     no_auto_search = kwargs.get('no_auto_search')
-    if not no_auto_search:
-        if dbt_project_dir:
-            dbt_project_path = os.path.join(dbt_project_dir, "dbt_project.yml")
-        else:
-            dbt_project_path = dbtutil.search_dbt_project_path()
-
+    dbt_project_path = DbtUtil.get_dbt_project_path(dbt_project_dir, no_auto_search)
+    dbt_profiles_dir = kwargs.get('dbt_profiles_dir')
+    dbt_profile = kwargs.get('dbt_profile')
+    dbt_target = kwargs.get('dbt_target')
     if dbt_project_path:
-        console.print(f'[[bold green] DBT [/bold green]] Use the existing dbt project file: {dbt_project_path}')
+        FileSystem.set_working_directory(dbt_project_path)
 
-    config = Initializer.exec(dbt_project_path=dbt_project_path, dbt_profiles_dir=dbt_profiles_dir)
+    # TODO show the process and message to users
+    console.print(f'Initialize piperider to path {FileSystem.PIPERIDER_WORKSPACE_PATH}')
+
+    config = Initializer.exec(dbt_project_path=dbt_project_path, dbt_profiles_dir=dbt_profiles_dir,
+                              dbt_profile=dbt_profile,
+                              dbt_target=dbt_target,
+                              reload=False)
     if kwargs.get('debug'):
         for ds in config.dataSources:
             console.rule('Configuration')
@@ -130,120 +194,77 @@ def init(**kwargs):
         sys.exit(1)
 
     # Show the content of config.yml
-    Initializer.show_config()
+    Initializer.show_config_file()
 
 
-@cli.command(short_help='Check project configuration.', cls=TrackCommand)
+@cli.command(short_help='Check the configuraion and connection.', cls=TrackCommand)
+@add_options(dbt_related_options)
 @add_options(debug_option)
 def diagnose(**kwargs):
-    'Check project configuration, datasource, connections, and assertion configuration.'
+    'Check project configuration, datasource, and connections configuration.'
 
     console = Console()
+
+    # Search dbt project config files
+    dbt_project_dir = kwargs.get('dbt_project_dir')
+    no_auto_search = kwargs.get('no_auto_search')
+    dbt_project_path = DbtUtil.get_dbt_project_path(dbt_project_dir, no_auto_search)
+    dbt_profiles_dir = kwargs.get('dbt_profiles_dir')
+    dbt_profile = kwargs.get('dbt_profile')
+    dbt_target = kwargs.get('dbt_target')
+    if dbt_project_path:
+        FileSystem.set_working_directory(dbt_project_path)
+        # Only run initializer when dbt project path is provided
+        Initializer.exec(dbt_project_path=dbt_project_path, dbt_profiles_dir=dbt_profiles_dir, interactive=False,
+                         dbt_profile=dbt_profile, dbt_target=dbt_target)
+    elif is_piperider_workspace_exist() is False:
+        raise DbtProjectNotFoundError()
+
     console.print('Diagnosing...')
 
     console.print(f'[bold dark_orange]PipeRider Version:[/bold dark_orange] {__version__}')
 
-    if not Validator.diagnose():
+    from piperider_cli.validator import Validator
+    if not Validator.diagnose(dbt_profile=dbt_profile, dbt_target=dbt_target):
         sys.exit(1)
 
 
-@cli.command(short_help='Profile data source, run assertions, and generate report(s).', cls=TrackCommand)
+@cli.command(short_help='Execute a piperider run.', cls=TrackCommand)
 @click.option('--datasource', default=None, type=click.STRING, help='Datasource to use.', metavar='DATASOURCE_NAME')
-@click.option('--table', default=None, type=click.STRING, help='Table to use.', metavar='TABLE_NAME')
+@click.option('--table', default=None, type=click.STRING, help='Specify the name of a model/seed/source to profile.',
+              metavar='TABLE_NAME')
 @click.option('--output', '-o', default=None, type=click.STRING, help='Directory to save the results.')
 @click.option('--skip-report', is_flag=True, help='Skip generating report.')
-@click.option('--dbt-state', default=None, help='Directory of the the dbt state.')
+@click.option('--dbt-target-path', default=None, help='Configure the "target-path" of dbt.')
 @click.option('--dbt-list', is_flag=True, help='Associate with dbt list format input.')
-@click.option('--dbt-run-results', is_flag=True, help='Associate with dbt run results.')
+@click.option('--dbt-run-results', is_flag=True, help='Associate with dbt run results.',
+              hidden=True)  # For backward compatibility
 @click.option('--report-dir', default=None, type=click.STRING, help='Use a different report directory.')
 @click.option('--upload', is_flag=True, help='Upload the report to the PipeRider Cloud.')
 @click.option('--project', default=None, type=click.STRING, help='Specify the project name to upload.')
 @click.option('--share', default=False, is_flag=True, help='Enable public share of the report to PipeRider Cloud.')
-@click.option('--open', is_flag=True, help='Opens the generated report in the system\'s default browser')
+@click.option('--open', is_flag=True, help='Opens the generated report in the system\'s default browser.')
+@click.option('--skip-datasource', default=False, is_flag=True,
+              help='Skip accessing the connection of datasource.')
+@add_options([
+    dbt_select_option_builder(),
+    click.option('--state', default=None,
+                 help='If set, use the given directory as the source for JSON files to compare with this project.')
+])
+@add_options(dbt_related_options)
+@add_options(feature_flags)
 @add_options(debug_option)
 def run(**kwargs):
-    'Profile data source, run assertions, and generate report(s). By default, the raw results and reports are saved in ".piperider/outputs".'
+    """
+    Profile data source and generate report(s). By default, the raw results and reports are saved in ".piperider/outputs".
+    """
 
-    datasource = kwargs.get('datasource')
-    table = kwargs.get('table')
-    output = kwargs.get('output')
-    open_report = kwargs.get('open')
-    enable_share = kwargs.get('share')
-    skip_report = kwargs.get('skip_report')
-    dbt_state_dir = kwargs.get('dbt_state')
-    dbt_list = kwargs.get('dbt_list')
-    dbt_run_results = kwargs.get('dbt_run_results')
-    force_upload = kwargs.get('upload')
-    project_name = kwargs.get('project')
-
-    console = Console()
-
-    # True -> 1, False -> 0
-    if sum([True if table else False, dbt_list, dbt_run_results]) > 1:
-        console.print("[bold red]Error:[/bold red] "
-                      "['--table', '--dbt-list', '--dbt-run-results'] are mutually exclusive")
-        sys.exit(1)
-
-    dbt_resources = None
-    if dbt_list:
-        metrics = []
-        models = []
-        for dbt_resource in sys.stdin:
-            if dbt_resource.startswith('source:'):
-                continue
-            elif dbt_resource.startswith('metric:'):
-                metrics.append(dbt_resource.rstrip().replace('metric:', 'metric.'))
-            else:
-                models.append(dbt_resource.rstrip())
-        dbt_resources = dict(metrics=metrics, models=models)
-
-    ret = Runner.exec(datasource=datasource,
-                      table=table,
-                      output=output,
-                      skip_report=skip_report,
-                      dbt_state_dir=dbt_state_dir,
-                      dbt_run_results=dbt_run_results,
-                      dbt_resources=dbt_resources,
-                      report_dir=kwargs.get('report_dir'))
-    if ret in (0, EC_ERR_TEST_FAILED):
-        if enable_share:
-            force_upload = True
-
-        auto_upload = CloudConnector.is_auto_upload()
-        is_cloud_view = (force_upload or auto_upload)
-
-        if not skip_report:
-            GenerateReport.exec(None, kwargs.get('report_dir'), output, open_report, is_cloud_view)
-
-        if CloudConnector.is_login() and is_cloud_view:
-            CloudConnector.upload_latest_report(report_dir=kwargs.get('report_dir'), debug=kwargs.get('debug'),
-                                                open_report=open_report, enable_share=enable_share,
-                                                project_name=project_name)
-    if ret != 0:
-        sys.exit(ret)
-    return ret
-
-
-@cli.command(short_help='Generate recommended assertions.', cls=TrackCommand)
-@click.option('--input', default=None, type=click.Path(exists=True), help='Specify the raw result file.')
-@click.option('--no-recommend', is_flag=True, help='Generate assertions templates only.')
-@click.option('--report-dir', default=None, type=click.STRING, help='Use a different report directory.')
-@click.option('--table', default=None, type=click.STRING, help='Generate assertions for the given table')
-@add_options(debug_option)
-def generate_assertions(**kwargs):
-    'Generate recommended assertions based on the latest result. By default, the profiling result will be loaded from ".piperider/outputs".'
-    input_path = kwargs.get('input')
-    report_dir = kwargs.get('report_dir')
-    no_recommend = kwargs.get('no_recommend')
-    table = kwargs.get('table')
-    ret = AssertionGenerator.exec(input_path=input_path, report_dir=report_dir, no_recommend=no_recommend, table=table)
-    if ret != 0:
-        sys.exit(ret)
-    return ret
+    from piperider_cli.cli_utils.run_cmd import run as cmd
+    return cmd(**kwargs)
 
 
 @cli.command(short_help='Generate a report.', cls=TrackCommand)
-@click.option('--input', default=None, type=click.Path(exists=True), help='Specify the raw result file.')
+@click.option('--input', default=None, type=RunDataPath(), help='Specify the raw result file.')
 @click.option('--output', '-o', default=None, type=click.STRING, help='Directory to save the results.')
 @click.option('--report-dir', default=None, type=click.STRING, help='Use a different report directory.')
 @add_options(debug_option)
@@ -253,8 +274,8 @@ def generate_report(**kwargs):
 
 
 @cli.command(short_help='Compare two existing reports.', cls=TrackCommand)
-@click.option('--base', default=None, type=click.Path(exists=True), help='Specify the base report file.')
-@click.option('--target', default=None, type=click.Path(exists=True), help='Specify the report file to be compared.')
+@click.option('--base', default=None, type=RunDataPath(), help='Specify the base report file.')
+@click.option('--target', default=None, type=RunDataPath(), help='Specify the report file to be compared.')
 @click.option('--last', default=None, is_flag=True, help='Compare the last two reports.')
 @click.option('--datasource', default=None, type=click.STRING, metavar='DATASOURCE_NAME',
               help='Specify the datasource.')
@@ -269,6 +290,7 @@ def generate_report(**kwargs):
               help='Specify the project name to upload.')
 @click.option('--share', default=False, is_flag=True, help='Enable public share of the report to PipeRider Cloud.')
 @click.option('--open', is_flag=True, help='Opens the generated report in the system\'s default browser')
+@add_options(feature_flags)
 @add_options(debug_option)
 def compare_reports(**kwargs):
     'Compare two existing reports selected in interactive mode or by option.'
@@ -280,22 +302,14 @@ def compare_reports(**kwargs):
     tables_from = kwargs.get('tables_from')
     summary_file = kwargs.get('summary_file')
     open_report = kwargs.get('open')
-    force_upload = kwargs.get('upload')
-    enable_share = kwargs.get('share')
     project_name = kwargs.get('project')
 
-    if enable_share or CloudConnector.is_auto_upload():
-        force_upload = True
-
-    if force_upload is True and CloudConnector.is_login() is False:
-        raise RecipeConfigException(
-            message='Please login to PipeRider Cloud first.',
-            hint='Run "piprider cloud login" to login to PipeRider Cloud.'
-        )
+    enable_upload, enable_share = verify_upload_related_options(**kwargs)
 
+    from piperider_cli.compare_report import CompareReport
     CompareReport.exec(a=a, b=b, last=last, datasource=datasource,
                        report_dir=kwargs.get('report_dir'), output=kwargs.get('output'), summary_file=summary_file,
-                       tables_from=tables_from, force_upload=force_upload, enable_share=enable_share,
+                       tables_from=tables_from, force_upload=enable_upload, enable_share=enable_share,
                        open_report=open_report, project_name=project_name, debug=kwargs.get('debug', False),
                        show_progress=True)
 
@@ -332,13 +346,13 @@ def delete(**kwargs):
 
 @config.command(name='enable-auto-upload', short_help='Enable auto upload to PipeRider Cloud.', cls=TrackCommand)
 def enable_auto_upload(**kwargs):
-    CloudConnector.config_auto_upload(True)
+    CloudConnectorHelper.config_auto_upload(True)
     pass
 
 
 @config.command(name='disable-auto-upload', short_help='Disable auto upload to PipeRider Cloud.', cls=TrackCommand)
 def disable_auto_upload(**kwargs):
-    CloudConnector.config_auto_upload(False)
+    CloudConnectorHelper.config_auto_upload(False)
     pass
 
 
@@ -359,7 +373,7 @@ def cloud(**kwargs):
 
 
 @cloud.command(short_help='Upload a report to the PipeRider Cloud.', cls=TrackCommand)
-@click.option('--run', type=click.Path(exists=True), help='Specify the raw result file.')
+@click.option('--run', type=RunDataPath(), help='Specify the raw result file.')
 @click.option('--report-dir', default=None, type=click.STRING, help='Use a different report directory.')
 @click.option('--datasource', default=None, type=click.STRING, metavar='DATASOURCE_NAME',
               help='Specify the datasource.')
@@ -374,9 +388,9 @@ def upload_report(**kwargs):
     datasource = kwargs.get('datasource')
     report_dir = kwargs.get('report_dir')
     project_name = kwargs.get('project')
-    ret = CloudConnector.upload_report(report_path=report_path, datasource=datasource, report_dir=report_dir,
-                                       project_name=project_name,
-                                       debug=kwargs.get('debug', False))
+    ret = CloudConnectorHelper.upload_report(report_path=report_path, datasource=datasource, report_dir=report_dir,
+                                             project_name=project_name,
+                                             debug=kwargs.get('debug', False))
     return ret
 
 
@@ -402,64 +416,71 @@ def cloud_compare_reports(**kwargs):
     summary_file = kwargs.get('summary_file')
     project_name = kwargs.get('project')
 
-    ret = CloudConnector.compare_reports(base=base, target=target, tables_from=tables_from, summary_file=summary_file,
-                                         project_name=project_name, debug=kwargs.get('debug', False))
+    ret = CloudConnectorHelper.compare_reports(base=base, target=target, tables_from=tables_from,
+                                               summary_file=summary_file,
+                                               project_name=project_name, debug=kwargs.get('debug', False))
 
     if ret != 0:
         sys.exit(ret)
     return ret
 
 
-@cli.command(name='compare', short_help='Generate comparison report with the recipe.', cls=TrackCommand)
+@cli.command(name='compare', short_help='Compare the change for the current branch.', cls=TrackCommand)
+@click.argument('ref', required=False, type=click.STRING)
 @click.option('--recipe', default=None, type=click.STRING, help='Select a different recipe.')
 @click.option('--upload', default=False, is_flag=True, help='Upload the report to PipeRider Cloud.')
 @click.option('--share', default=False, is_flag=True, help='Enable public share of the report to PipeRider Cloud.')
 @click.option('--output', '-o', default=None, type=click.STRING, help='Directory to save the results.')
 @click.option('--summary-file', default=None, type=click.STRING, help='Output the comparison summary markdown file.')
+@click.option('--project', default=None, type=click.STRING, metavar='PROJECT_NAME',
+              help='Specify the default project name.')
 @click.option('--open', is_flag=True, help='Opens the generated report in the system\'s default browser')
+@click.option('--dry-run', is_flag=True, default=False, help='Display the run details without actually executing it')
+@click.option('--interactive', is_flag=True, default=False,
+              help='Prompt for confirmation to proceed with the run (Y/N)')
+@click.option('--skip-datasource', default=False, is_flag=True, help='Skip accessing the connection of datasource.')
+@add_options([
+    dbt_select_option_builder(),
+    click.option('--modified', default=False, is_flag=True, help='Only compare the modified models.'),
+    click.option('--base-branch', type=click.STRING, help='Specify the base branch for an auto-generated recipe.',
+                 show_default=True),
+])
+@add_options(dbt_related_options)
+@add_options(feature_flags)
 @add_options(debug_option)
-def compare_with_recipe(**kwargs):
+def compare_with_recipe(ref, **kwargs):
     """
-    Generate comparison report with the recipe
+    Generate the comparison report for your branch.
+
+    \b
+    # compare with main/master branch
+    piperider compare
+
+    \b
+    # compare with specific branch
+    piperider compare --base-branch <branch>
+
+    \b
+    # compare with any reference
+    piperider compare <git-ref>
+
+    \b
+    # compare with two references
+    piperider compare <git-ref>...<git-ref>
+
+    \b
+    Note: <git-ref> can be reference that git understands. e.g., branch, tag, commit, etc.
+
     """
 
-    recipe = kwargs.get('recipe')
-    summary_file = kwargs.get('summary_file')
-    force_upload = kwargs.get('upload')
-    enable_share = kwargs.get('share')
-    open_report = kwargs.get('open')
-    debug = kwargs.get('debug', False)
-
-    if enable_share:
-        force_upload = True
-
-    if force_upload is True and CloudConnector.is_login() is False:
-        raise RecipeConfigException(
-            message='Please login to PipeRider Cloud first.',
-            hint='Run "piprider cloud login" to login to PipeRider Cloud.'
-        )
-
-    ret = 0
-    try:
-        RecipeExecutor.exec(recipe_name=recipe, debug=debug)
-        CompareReport.exec(a=None, b=None, last=True, datasource=None,
-                           output=kwargs.get('output'), tables_from="all",
-                           summary_file=summary_file,
-                           force_upload=force_upload,
-                           enable_share=enable_share,
-                           open_report=open_report,
-                           show_progress=True,
-                           debug=debug)
-    except Exception as e:
-        raise e
-
-    return ret
+    from piperider_cli.cli_utils.compare_with_recipe import compare_with_recipe as cmd
+    return cmd(ref, **kwargs)
 
 
 @cloud.command(short_help='Signup to PipeRider Cloud.', cls=TrackCommand)
 @add_options(debug_option)
 def signup(**kwargs):
-    ret = CloudConnector.signup(debug=kwargs.get('debug', False))
+    ret = CloudConnectorHelper.signup(debug=kwargs.get('debug', False))
     return ret
 
 
@@ -479,21 +500,21 @@ def login(**kwargs):
     if kwargs.get('no_interaction') is True:
         options['no_interaction'] = True
 
-    ret = CloudConnector.login(api_token=kwargs.get('token'), options=options, debug=kwargs.get('debug', False))
+    ret = CloudConnectorHelper.login(api_token=kwargs.get('token'), options=options, debug=kwargs.get('debug', False))
     return ret
 
 
 @cloud.command(short_help='Logout from PipeRider Cloud.', cls=TrackCommand)
 @add_options(debug_option)
 def logout(**kwargs):
-    ret = CloudConnector.logout()
+    ret = CloudConnectorHelper.logout()
     return ret
 
 
 @cloud.command(short_help='List projects on PipeRider Cloud.', cls=TrackCommand)
 @add_options(debug_option)
 def list_projects(**kwargs):
-    ret = CloudConnector.list_projects()
+    ret = CloudConnectorHelper.list_projects()
     return ret
 
 
@@ -505,5 +526,5 @@ def list_projects(**kwargs):
 def select_project(**kwargs):
     project_name = kwargs.get('project')
     no_interaction: bool = kwargs.get('no_interaction', False)
-    ret = CloudConnector.select_project(project_name=project_name, no_interaction=no_interaction)
+    ret = CloudConnectorHelper.select_project(project_name=project_name, no_interaction=no_interaction)
     return ret
