@@ -1,14 +1,15 @@
 import json
 import os
-from typing import List
+from json import JSONDecodeError
+from typing import List, Union
 
 import requests
 from requests_toolbelt import MultipartEncoder, MultipartEncoderMonitor
 from rich.progress import Progress, TextColumn, BarColumn, DownloadColumn, TimeElapsedColumn
-from ruamel import yaml
 
 from piperider_cli import __version__
-from piperider_cli.error import PipeRiderNoDefaultProjectError
+from piperider_cli.configuration import Configuration
+from piperider_cli.error import PipeRiderNoDefaultProjectError, CloudReportError, PipeRiderConfigError
 from piperider_cli.event import load_user_profile, update_user_profile
 
 PIPERIDER_CLOUD_SERVICE = 'https://cloud.piperider.io/'
@@ -16,8 +17,6 @@ PIPERIDER_CLOUD_SERVICE = 'https://cloud.piperider.io/'
 SERVICE_ENV_API_KEY = 'PIPERIDER_API_TOKEN'
 SERVICE_ENV_SERVICE_KEY = 'PIPERIDER_API_SERVICE'
 
-yml = yaml.YAML()
-
 
 class PipeRiderProject(object):
     def __init__(self, project: dict):
@@ -26,6 +25,11 @@ class PipeRiderProject(object):
         self.workspace_name = project.get('workspace_name')
 
 
+class PipeRiderTemporaryProject(PipeRiderProject):
+    def __init__(self):
+        super().__init__({'id': None, 'name': None, 'workspace_name': None})
+
+
 class CloudServiceHelper:
 
     def __init__(self):
@@ -34,7 +38,7 @@ class CloudServiceHelper:
         self.user_profile = load_user_profile()
         if self.user_profile is None:
             return
-        self.load_configuration()
+        self.load_cloud_api_config()
 
     @property
     def cloud_host(self):
@@ -42,7 +46,7 @@ class CloudServiceHelper:
             return 'http://localhost:3000'
         return self.api_service
 
-    def load_configuration(self):
+    def load_cloud_api_config(self):
         # load from the configuration file first
         # overwrite them if found env vars
         self.api_service = os.environ.get(SERVICE_ENV_SERVICE_KEY,
@@ -52,13 +56,27 @@ class CloudServiceHelper:
                                         self.user_profile.get('api_token'))
 
     def get_config(self) -> dict:
-        config = self.user_profile.get('cloud_config', {})
+        # precedence: local cloud config > global profiler cloud config
+        config = {}
+        try:
+            config = Configuration.instance().cloud_config
+        except PipeRiderConfigError:
+            # piperider may not be initialized
+            pass
+
+        if not config.get('default_project'):
+            config.update(self.user_profile.get('cloud_config', {}))
+
         return config if config else {}
 
     def update_config(self, options: dict):
         cloud_config = self.get_config()
         cloud_config.update(options)
-        self.user_profile = update_user_profile({'cloud_config': cloud_config})
+        try:
+            Configuration.update_config('cloud_config', cloud_config)
+            Configuration.instance().cloud_config = cloud_config
+        except FileNotFoundError:
+            self.user_profile = update_user_profile({'cloud_config': cloud_config})
 
     def update_api_token(self):
         if self.api_token:
@@ -74,6 +92,11 @@ class CloudServiceHelper:
             return f'{self.api_service[:-1]}{uri_path}'
         return f'{self.api_service}{uri_path}'
 
+    def non_auth_header(self):
+        return {
+            'User-Agent': f'PipeRider CLI/{__version__}',
+        }
+
     def auth_headers(self):
         return {
             'User-Agent': f'PipeRider CLI/{__version__}',
@@ -102,13 +125,14 @@ class CloudServiceHelper:
 class PipeRiderCloud:
 
     def __init__(self):
-        self.service = CloudServiceHelper()
-        self.config: dict = self.service.get_config()
         try:
+            self.service = CloudServiceHelper()
+            self.config: dict = self.service.get_config()
             self.available, self.me = self.service.validate()
         except BaseException:
             self.available = False
             self.me = None
+            self.config: dict = {}
 
     def update_config(self, options: dict):
         self.service.update_config(options)
@@ -182,14 +206,15 @@ class PipeRiderCloud:
         if response.status_code != 200:
             return None
 
-        responseData = response.json()
+        response_data = response.json()
 
-        def genProjects():
-            for workspace in responseData.get('data', []):
-                for project in workspace.get('projects', []):
-                    yield project
+        def gen_projects():
+            for workspace in response_data.get('data', []):
+                for workspace_project in workspace.get('projects', []):
+                    workspace_project['workspace_name'] = workspace.get('name')
+                    yield workspace_project
 
-        projects = list(genProjects())
+        projects = list(gen_projects())
         if len(projects) == 1:
             return PipeRiderProject(projects[0])
         else:
@@ -241,11 +266,32 @@ class PipeRiderCloud:
 
         return response.json()
 
-    def upload_run(self, file_path, show_progress=True, project: PipeRiderProject = None):
-        # TODO validate project name
+    def get_datasource_id(self, project: PipeRiderProject):
         if not self.available:
             self.raise_error()
 
+        url = self.service.url(f'/api/v2/workspaces/{project.workspace_name}/projects/{project.name}/runs/latest')
+        headers = self.service.auth_headers()
+        response = requests.get(url, headers=headers)
+
+        if response.status_code != 200:
+            return None
+
+        content = response.json()
+        return content.get('datasource_id')
+
+    def upload_run(self, file_path, show_progress=True, project: PipeRiderProject = None):
+        # TODO validate project name
+        if isinstance(project, PipeRiderTemporaryProject):
+            api_url = self.service.url('/api/v2/temporary/runs/upload')
+            headers = self.service.non_auth_header()
+        else:
+            api_url = self.service.url(
+                f'/api/v2/workspaces/{project.workspace_name}/projects/{project.name}/runs/upload')
+            if not self.available:
+                self.raise_error()
+            headers = self.service.auth_headers()
+
         upload_progress = None
         task_id = None
 
@@ -258,10 +304,6 @@ class PipeRiderCloud:
                 fields={'file': ('run.json', file)},
             )
             m = MultipartEncoderMonitor(encoder, _upload_callback)
-
-            url = self.service.url(
-                f'/api/v2/workspaces/{project.workspace_name}/projects/{project.name}/runs/upload')
-            headers = self.service.auth_headers()
             headers['Content-Type'] = m.content_type
 
             if show_progress:
@@ -274,12 +316,17 @@ class PipeRiderCloud:
                 task_id = upload_progress.add_task(description=file_path, total=encoder.len)
                 upload_progress.start()
 
-            response = requests.post(url, data=m, headers=headers)
+            response = requests.post(api_url, data=m, headers=headers)
 
             if show_progress:
                 upload_progress.stop()
 
-            return response.json()
+            try:
+                response_data = response.json()
+            except JSONDecodeError:
+                response_data = {"success": False, "message": response.reason}
+
+            return response_data
 
     def share_run_report(self, workspace_name: str, project_name: str, run_id: int):
         if not self.available:
@@ -291,21 +338,28 @@ class PipeRiderCloud:
         response = requests.post(url, headers=headers)
 
         if response.status_code != 200:
-            return None
+            self.raise_error(response.reason)
 
         return response.json()
 
-    def compare_reports(self, base_id: int, target_id: int, tables_from, project: PipeRiderProject):
-        if not self.available:
-            self.raise_error()
+    def compare_reports(self, base_id: Union[int, str], target_id: Union[int, str], tables_from,
+                        project: PipeRiderProject,
+                        metadata: dict = None):
+        if isinstance(project, PipeRiderTemporaryProject):
+            api_url = self.service.url(f'/api/v2/temporary/runs/{base_id}/compare/{target_id}')
+            headers = self.service.non_auth_header()
+        else:
+            if not self.available:
+                self.raise_error()
+            api_url = self.service.url(
+                f'/api/v2/workspaces/{project.workspace_name}/projects/{project.name}/runs/{base_id}/compare/{target_id}')
+            headers = self.service.auth_headers()
 
-        url = self.service.url(
-            f'/api/v2/workspaces/{project.workspace_name}/projects/{project.name}/runs/{base_id}/compare/{target_id}')
-        headers = self.service.auth_headers()
-        response = requests.post(url, data=json.dumps({'tables_from': tables_from}), headers=headers)
+        data = json.dumps({'tables_from': tables_from, 'metadata': metadata})
+        response = requests.post(api_url, data=data, headers=headers)
 
         if response.status_code != 200:
-            return None
+            self.raise_error(response.reason)
 
         return response.json()
 
@@ -319,12 +373,12 @@ class PipeRiderCloud:
         response = requests.post(url, headers=headers)
 
         if response.status_code != 200:
-            return None
+            self.raise_error(response.reason)
 
         return response.json()
 
-    def raise_error(self):
-        raise ValueError("Service not available or configuration invalid")
+    def raise_error(self, message="Service not available or configuration invalid"):
+        raise CloudReportError(message)
 
     def has_configured(self):
         return self.service.api_token is not None
