@@ -2,7 +2,7 @@ import json
 import os
 import sys
 import webbrowser
-from typing import List, Optional
+from typing import List, Optional, Union
 
 import inquirer
 import readchar
@@ -12,10 +12,12 @@ from rich.prompt import Prompt
 from rich.table import Table
 
 from piperider_cli import datetime_to_str, open_report_in_browser, str_to_datetime, get_run_json_path
-from piperider_cli.cloud import PipeRiderCloud, PipeRiderProject
+from piperider_cli.cloud import PipeRiderCloud, PipeRiderProject, PipeRiderTemporaryProject
 from piperider_cli.compare_report import CompareReport, RunOutput
+from piperider_cli.configuration import Configuration
 from piperider_cli.datasource import FANCY_USER_INPUT
-from piperider_cli.filesystem import FileSystem
+from piperider_cli.error import CloudReportError
+from piperider_cli.githubutil import fetch_pr_metadata
 
 console = Console()
 piperider_cloud = PipeRiderCloud()
@@ -176,7 +178,7 @@ def setup_cloud_default_config(options: dict = None):
 
 
 def select_reports(report_dir=None, datasource=None) -> List[RunOutput]:
-    filesystem = FileSystem(report_dir=report_dir)
+    filesystem = Configuration.instance().activate_report_directory(report_dir=report_dir)
     selector = CompareReport(filesystem.get_output_dir(), None, None, datasource=datasource)
     console.rule('Select Reports to Upload')
     return selector.select_multiple_reports(action='upload')
@@ -234,11 +236,17 @@ def upload_to_cloud(run: RunOutput, debug=False, project: PipeRiderProject = Non
     def _patch_cloud_upload_response(run_path, project: PipeRiderProject, run_id):
         with open(run_path, 'r') as f:
             report = json.load(f)
-        report['cloud'] = {
-            'run_id': run_id,
-            'project_name': f'{project.workspace_name}/{project.name}'
-        }
-        with open(run_path, 'w') as f:
+        if isinstance(project, PipeRiderTemporaryProject):
+            report['cloud'] = {
+                'run_id': run_id,
+                'is_temporary': True,
+            }
+        else:
+            report['cloud'] = {
+                'run_id': run_id,
+                'project_name': f'{project.workspace_name}/{project.name}'
+            }
+        with open(run_path, 'w', encoding='utf-8') as f:
             f.write(json.dumps(report, separators=(',', ':')))
 
     if response.get('success') is True:
@@ -281,10 +289,12 @@ def get_run_report_id(project: PipeRiderProject, report_key: str) -> Optional[in
     return None
 
 
-def create_compare_reports(base_id: str, target_id: str, tables_from, project: PipeRiderProject = None) -> dict:
+def create_compare_reports(base_id: Union[str, int], target_id: Union[str, int], tables_from,
+                           project: PipeRiderProject = None,
+                           metadata: dict = None) -> dict:
     if project is None:
         project = piperider_cloud.get_default_project()
-    response = piperider_cloud.compare_reports(base_id, target_id, tables_from, project=project)
+    response = piperider_cloud.compare_reports(base_id, target_id, tables_from, project=project, metadata=metadata)
     return response
 
 
@@ -359,7 +369,7 @@ class CloudConnector:
     @staticmethod
     def upload_latest_report(report_dir=None, debug=False, open_report=False, enable_share=False,
                              project_name: str = None) -> int:
-        filesystem = FileSystem(report_dir=report_dir)
+        filesystem = Configuration.instance().activate_report_directory(report_dir=report_dir)
         latest_report_path = get_run_json_path(filesystem.get_output_dir())
         return CloudConnector.upload_report(latest_report_path, debug=debug, open_report=open_report,
                                             enable_share=enable_share, project_name=project_name)
@@ -367,7 +377,10 @@ class CloudConnector:
     @staticmethod
     def upload_report(report_path=None, report_dir=None, datasource=None, debug=False, open_report=False,
                       enable_share=False, project_name=None, show_progress=True) -> int:
-        if piperider_cloud.available is False:
+        is_temporary_report = False
+        if piperider_cloud.available is False and enable_share is True:
+            is_temporary_report = True
+        elif piperider_cloud.available is False:
             console.rule('Please login PipeRider Cloud first', style='red')
             return 1
 
@@ -376,6 +389,8 @@ class CloudConnector:
             if project is None:
                 console.print(f'[[bold red]Error[/bold red]] Project \'{project_name}\' does not exist')
                 return 1
+        elif is_temporary_report:
+            project = PipeRiderTemporaryProject()
         else:
             project = piperider_cloud.get_default_project()
 
@@ -407,44 +422,53 @@ class CloudConnector:
             console.rule('Upload Completed')
             ascii_table = Table(show_header=True, show_edge=True, header_style="bold magenta",
                                 box=box.SIMPLE)
+            ascii_table.add_column('ID', justify='left', style='cyan')
             ascii_table.add_column('Status', justify='left', style='cyan')
             ascii_table.add_column('Name', justify='left')
             ascii_table.add_column('Created At', justify='left')
-            ascii_table.add_column('Report URL', justify='left', no_wrap=True)
             ascii_table.add_column('Message', justify='left')
 
+            reports = []
             for response in results:
                 status = '[bold green]Success[/bold green]' if response.get(
                     'success') else '[bold yellow]Skipped[/bold yellow]'
-                url = f"[deep_sky_blue1]{response.get('report_url', 'N/A')}[/deep_sky_blue1]"
+                reports.append((response.get('run_id'), response.get('report_url', 'N/A')))
                 message = response.get('message')
                 created_at = datetime_to_str(str_to_datetime(response.get('created_at')), to_tzlocal=True)
-                ascii_table.add_row(status, response.get('name'), created_at, url, message)
+                ascii_table.add_row(str(response.get('run_id')), status, response.get('name'), created_at, message)
             console.print(ascii_table)
 
+            for report in reports:
+                console.print(f'Report #{report[0]} URL: [deep_sky_blue1]{report[1]}?utm_source=cli[/deep_sky_blue1]',
+                              soft_wrap=True)
+
         if open_report:
             url = response.get('report_url')
             open_report_in_browser(url, True)
 
-        if enable_share:
+        if enable_share and is_temporary_report is False:
             run_id = response.get('run_id')
-            CloudConnector.share_run_report(run_id, debug)
+            CloudConnector.share_run_report(run_id, debug, project_name=project_name)
 
         return rc
 
     @staticmethod
     def generate_compare_report(base_id: str, target_id: str, tables_from='all',
-                                project_name: str = None, debug: bool = False):
+                                project_name: str = None, is_temporary: bool = False, debug: bool = False):
         # TODO: Change to use new front-end URL pattern
         def _generate_legacy_compare_report_url(base_id, target_id, project=None):
+            metadata = fetch_pr_metadata()
             if project is None:
                 project = piperider_cloud.get_default_project()
-            response = create_compare_reports(base_id, target_id, tables_from, project=project)
+
+            response = create_compare_reports(base_id, target_id, tables_from, project=project, metadata=metadata)
             return response
 
         try:
             # TODO: change to use workspace and project name instead of project id
-            if project_name:
+            if is_temporary is True:
+                project = PipeRiderTemporaryProject()
+            elif project_name:
                 project = piperider_cloud.get_project_by_name(project_name)
                 if project is None:
                     console.print(f'[[bold red]Error[/bold red]] Project \'{project_name}\' does not exist')
@@ -452,9 +476,8 @@ class CloudConnector:
             else:
                 project = piperider_cloud.get_default_project()
             return _generate_legacy_compare_report_url(base_id, target_id, project=project)
-        except Exception as e:
-            if debug:
-                console.print(f'[[bold red]Error[/bold red]] {e}')
+        except CloudReportError as e:
+            console.print(f'[[bold red]Error[/bold red]] Cannot generate compare report in the cloud: {e.message}')
             return None
 
     @staticmethod
@@ -479,12 +502,15 @@ class CloudConnector:
                 f'Please upload reports to PipeRider Cloud first.')
 
         console.print(f"Creating comparison report id={base_id} ... id={target_id}")
-        response = create_compare_reports(base_id, target_id, tables_from, project=project)
+
+        metadata = fetch_pr_metadata()
+
+        response = create_compare_reports(base_id, target_id, tables_from, project=project, metadata=metadata)
         if response is None:
             console.print('Failed to create the comparison report')
         else:
             url = response.get('url')
-            console.print(f'Comparison report URL: {url}')
+            console.print(f'Comparison report URL: {url}?utm_source=cli')
 
         if debug:
             console.print(response)
@@ -494,16 +520,20 @@ class CloudConnector:
             summary_dir = os.path.dirname(summary_file)
             if summary_dir:
                 os.makedirs(summary_dir, exist_ok=True)
-            with open(summary_file, 'w') as f:
+            with open(summary_file, 'w', encoding='utf-8') as f:
                 f.write(response.get('summary'))
 
     @staticmethod
-    def share_run_report(run_id=None, debug=False):
+    def share_run_report(run_id=None, debug=False, project_name=None):
         if piperider_cloud.available is False:
             console.rule('Please login PipeRider Cloud first', style='red')
             return 1
 
-        workspace_name, project_name = piperider_cloud.get_default_workspace_and_project()
+        if project_name is None:
+            workspace_name, project_name = piperider_cloud.get_default_workspace_and_project()
+        else:
+            workspace_name, project_name = project_name.split('/')
+
         if workspace_name is None or project_name is None:
             console.rule('Please select a workspace and a project first', style='red')
             return 1
@@ -517,12 +547,16 @@ class CloudConnector:
         )
 
     @staticmethod
-    def share_compare_report(base_id=None, target_id=None, debug=False):
+    def share_compare_report(base_id=None, target_id=None, debug=False, project_name=None):
         if piperider_cloud.available is False:
             console.rule('Please login PipeRider Cloud first', style='red')
             return 1
 
-        workspace_name, project_name = piperider_cloud.get_default_workspace_and_project()
+        if project_name is None:
+            workspace_name, project_name = piperider_cloud.get_default_workspace_and_project()
+        else:
+            workspace_name, project_name = project_name.split('/')
+
         if workspace_name is None or project_name is None:
             console.rule('Please select a workspace and a project first', style='red')
             return 1
