@@ -115,3 +115,13 @@ class SnowflakeDataSource(DataSource):
             return None
         except Exception as e:
             return PipeRiderConnectorError(str(e), 'snowflake')
+
+    def _get_display_description(self):
+        cred = self.credential
+        return f"type={self.type_name}, database={cred.get('database')}, schema={cred.get('schema')}"
+
+    def get_database(self):
+        return self.credential.get('database')
+
+    def get_schema(self):
+        return self.credential.get('schema')
