@@ -8,16 +8,6 @@ class UserSurveyMockDataSource(DataSource):
     def __init__(self, name, **kwargs):
         super().__init__(name, 'datasource survey', **kwargs)
         self.fields = [
-            ListField('datasource_candidates',
-                      description='Data Source Candidates',
-                      default=[
-                          'Azure Synapse Analytics',
-                          'IBM Db2 Warehouse',
-                          'SAP Data Warehouse Cloud',
-                          'Other',
-                      ]),
-            TextField('other', description='Please tell what data source you want us to supported',
-                      ignore=lambda answers: answers['datasource_candidates'] != 'Other'),
         ]
 
     # Always return None to prevent it generate the configue files
@@ -35,6 +25,15 @@ class UserSurveyMockDataSource(DataSource):
         return PipeRiderError('',
                               hint="Thanks for your feedback. We will improve Piperider in the future.\nPlease execute command 'piperider init' with supported data source.")
 
+    def _get_display_description(self):
+        return ''
+
+    def get_database(self):
+        return ''
+
+    def get_schema(self):
+        return ''
+
     def send_survey(self):
         datasource = self.credential.get('datasource_candidates')
         if datasource == 'Other':
