@@ -21,8 +21,8 @@ class PipeRiderConfigError(PipeRiderError):
         self.config_file = config_file
         pass
 
-    message = "Piperider is not initialized."
-    hint = "Please execute command 'piperider init' to move forward."
+    message = "PipeRider configuration file not found."
+    hint = "Please follow the Quick Start guide on https://docs.piperider.io/get-started/quick-start to set up your first PipeRider project."
 
 
 class PipeRiderConfigTypeError(PipeRiderError):
@@ -69,6 +69,13 @@ class PipeRiderConnectorError(PipeRiderError):
         self.hint = f'Please run \"pip install \'piperider[{datasource_name}]\'\" to get the {datasource_name} connector'
 
 
+class PipeRiderConnectorUnsupportedError(PipeRiderError):
+    def __init__(self, err_msg, datasource_type):
+        self.message = err_msg
+        self.hint = (f'Please contact us to support \'{datasource_type}\' connector by '
+                     f'https://github.com/InfuseAI/piperider/issues/new/choose')
+
+
 class PipeRiderTableConnectionError(PipeRiderError):
     def __init__(self, name, type_name):
         self.message = f'No available table found or no access permission found from \'{name}\' data source.'
@@ -111,11 +118,14 @@ class DbtError(PipeRiderError):
 
 
 class DbtProjectNotFoundError(DbtError):
-    def __init__(self, dbt_project_path):
+    def __init__(self, dbt_project_path=None):
         self.dbt_project_path = dbt_project_path
-        self.message = f"Cannot find dbt project at '{dbt_project_path}'."
+        if dbt_project_path:
+            self.message = f"No DBT project found in '{dbt_project_path}'"
+        else:
+            self.message = "No DBT project found in current path"
 
-    hint = "Please make sure the dbt project is in the same directory with the piperider config file."
+    hint = "Please follow the Quick Start guide on https://docs.piperider.io/get-started/quick-start to set up your first PipeRider project."
 
 
 class DbtProjectInvalidError(DbtError):
@@ -161,6 +171,17 @@ class DbtAdapterCommandNotFoundError(PipeRiderError):
         self.hint = f'Please run \'pip install dbt-{datasource_type}\' to install dbt Core and the adapter.'
 
 
+class DbtRunTimeError(PipeRiderError):
+    def __init__(self, err: RuntimeError, select=None, state=None):
+        self.message = err.msg if hasattr(err, 'msg') else str(err)
+        hint_cmd = 'dbt list'
+        if select:
+            hint_cmd = f'{hint_cmd} --select {",".join(select)}'
+        if state:
+            hint_cmd = f'{hint_cmd} --state {state}'
+        self.hint = f"Please make sure the select options are correct by executing '{hint_cmd}'."
+
+
 class AssertionError(PipeRiderError):
     def __init__(self, error_msg):
         self.message = error_msg
@@ -189,10 +210,22 @@ class AwsUnExistedS3Bucket(PipeRiderError):
 class RecipeException(PipeRiderError):
     def __init__(self, message):
         self.message = message
-        self.hint = 'Please use "git stash" to stash your changes or "git commit" to permanently save changes to current branch.'
 
 
 class RecipeConfigException(PipeRiderError):
     def __init__(self, message, hint=None):
         self.message = message
         self.hint = hint
+
+
+class CloudReportError(PipeRiderError):
+    def __init__(self, error_msg):
+        self.message = error_msg
+        pass
+
+
+class PipeRiderConflictOptionsError(PipeRiderError):
+    def __init__(self, error_msg, hint=''):
+        self.message = error_msg
+        self.hint = hint
+        pass
