@@ -3,32 +3,14 @@ import os
 import platform
 import sys
 import time
+from contextlib import contextmanager
 from datetime import datetime
+from json import JSONDecodeError
 
 import portalocker
 import requests
 
-from piperider_cli import __version__
-from piperider_cli.configuration import PIPERIDER_WORKSPACE_NAME
-
-PIPERIDER_WORKING_DIR = os.path.join(os.getcwd(), PIPERIDER_WORKSPACE_NAME)
-PIPERIDER_EVENT_PATH = os.path.join(PIPERIDER_WORKING_DIR, '.unsend_events.json')
-
-
-def _is_executed_manually() -> bool:
-    # some CI service puts the "CI" var
-    if os.environ.get('CI', 'false') == 'true':
-        return False
-
-    # For CiecleCI exceptions
-    if os.environ.get('CIRCLECI', 'false') == 'true':
-        return False
-
-    # if not tty, it probably runs automatically
-    if not sys.stdout.isatty():
-        return False
-
-    return True
+from piperider_cli import __version__, is_executed_manually
 
 
 class Collector:
@@ -37,12 +19,10 @@ class Collector:
         self._api_key = None
         self._user_id = None
 
-        self._unsend_events_file = PIPERIDER_EVENT_PATH
+        self._unsend_events_file = None
         self._delete_threshold = 1000
         self._upload_threshold = 10
-        self._manual: bool = _is_executed_manually()
-
-        self._check_required_files()
+        self._manual: bool = is_executed_manually()
 
     def is_ready(self):
         if self._api_key is None or self._user_id is None:
@@ -55,6 +35,10 @@ class Collector:
     def set_user_id(self, user_id):
         self._user_id = user_id
 
+    def set_unsend_events_file(self, unsend_events_file):
+        self._unsend_events_file = unsend_events_file
+        self._check_required_files()
+
     def log_event(self, prop, event_type):
         # Use local timezone
         created_at = datetime.now()
@@ -82,15 +66,15 @@ class Collector:
             app_version=__version__,
         )
 
-        # TODO: handle exception when writing to file
         self._store_to_file(event)
         if self._is_full():
             self.send_events()
         self._cleanup_unsend_events()
 
     def _check_required_files(self):
-        if not os.path.exists(PIPERIDER_WORKING_DIR):
-            os.makedirs(PIPERIDER_WORKING_DIR, exist_ok=True)
+        user_home = os.path.dirname(self._unsend_events_file)
+        if not os.path.exists(user_home):
+            os.makedirs(user_home, exist_ok=True)
         if not os.path.exists(self._unsend_events_file):
             with portalocker.Lock(self._unsend_events_file, 'w+', timeout=5) as f:
                 f.write(json.dumps({'unsend_events': []}))
@@ -100,17 +84,27 @@ class Collector:
             o = json.loads(f.read())
             return len(o.get('unsend_events', [])) >= self._upload_threshold
 
-    def send_events(self):
+    @contextmanager
+    def load_json(self):
         with portalocker.Lock(self._unsend_events_file, 'r+', timeout=5) as f:
-            o = json.loads(f.read())
+            try:
+                o = json.loads(f.read())
+                yield o
+            except JSONDecodeError:
+                o = dict(unsend_events=[])
+                yield o
+            finally:
+                f.seek(0)
+                f.truncate()
+                f.write(json.dumps(o))
+
+    def send_events(self):
+        with self.load_json() as o:
             payload = dict(
                 api_key=self._api_key,
                 events=o['unsend_events'],
             )
             o['unsend_events'] = []
-            f.seek(0)
-            f.truncate()
-            f.write(json.dumps(o))
         try:
             requests.post(self._api_endpoint, json=payload)
         except Exception:
@@ -118,27 +112,18 @@ class Collector:
             pass
 
     def _store_to_file(self, event):
-        with portalocker.Lock(self._unsend_events_file, 'r+', timeout=5) as f:
-            o = json.loads(f.read())
+        with self.load_json() as o:
             events = o.get('unsend_events', None)
             if events is None:
                 o['unsend_events'] = []
 
             o['unsend_events'].append(event)
-            f.seek(0)
-            f.truncate()
-            f.write(json.dumps(o))
 
     def _cleanup_unsend_events(self):
-        with portalocker.Lock(self._unsend_events_file, 'r+', timeout=5) as f:
-            o = json.loads(f.read())
+        with self.load_json() as o:
             events = o.get('unsend_events', None)
             if events is None:
                 o['unsend_events'] = []
 
             while len(o['unsend_events']) > self._delete_threshold:
                 o['unsend_events'].pop(0)
-
-            f.seek(0)
-            f.truncate()
-            f.write(json.dumps(o))
